#ifndef UARTDRIVER_H
#define UARTDRIVER_H

//********************************************************************************************
//UARTDriver
//
//In main() you need the following lines of code to enable Interupt driven UART operation
//
//#include <avr/interrupt.h>
//
//UCSR0B |= (1 << RXCIE0); //enable UART Receive interupt
//sei(); // Enable the Global Interrupt Enable flag so that interrupts can be processed
//	
//YOU NEED TO PUT THE LAST FUNCTION IN THIS FILE INTO main() ALSO. One for each USARTn
//
//if it doesn't work after this it's an sei() issue.  Remember you fixed it by 
//rolling back to a previous WinAVR library.  Solution is to use volatile variables
//and something about ATOMIC.  See google.
//
//********************************************************************************************

//Map non existing UART registers to 0 to make older 644 happy
#define UBRR1H UBRR0H
#define UBRR1L UBRR0L
#define UCSR1B UCSR0B
#define UCSR1C UCSR0C
#define UCSR1A UCSR0A
#define UDR1 UDR0
#define RXEN1 RXEN0
#define TXEN1 TXEN0
#define URSEL1 URSEL0
#define USBS1 USBS0
#define UPM10 UPM01
#define UCSZ10 UCSZ00
#define UDRE1 UDRE0
#define RXC1 RXC0
#define RXCIE1 RXCIE0

#define EVEN_PARITY	2
#define ODD_PARITY	3
#define NO_PARITY	0

#include <avr/io.h>
#include <util/delay.h>
#include <string.h>
#include <stdio.h>


/*Prototypes*/
//UART
void USART_Init( unsigned int ubrr,unsigned char chan,unsigned char stopBits, unsigned char parity );
void USART_Transmit( unsigned char data,unsigned char chan );
unsigned char USART_Receive( unsigned char chan );
void USART_Transmit_16bit( unsigned short data,unsigned char chan );
void USART_Flush( unsigned char chan);
void USART_bootup( unsigned char chan );
void USART_transmitSENT(unsigned char chan, char * buf);
void UART_Transmit_GlobalArray(unsigned char source, unsigned char msgSize, char* msg);


#endif

